#
# spec file for package libotr
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libotr
Version:        4.1.1
Release:        4.5
Summary:        "Off The Record" messaging library toolkit
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://www.cypherpunks.ca/otr/
Source:         https://www.cypherpunks.ca/otr/%{name}-%{version}.tar.gz
Source1:        https://www.cypherpunks.ca/otr/%{name}-%{version}.tar.gz.asc
Source2:        http://www.cypherpunks.ca/otr/gpgkey.asc#/libotr.keyring
Patch0:         libotr-4.1.1-fix-base64-tests.patch
Patch1:         libotr-test-underrun.patch
Patch2:         libotr-test-uninitialized.patch
Patch3:         libotr-4.1.1-include-socket.h.patch
BuildRequires:  libgcrypt-devel >= 1.2.0
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Off-the-Record (OTR) Messaging allows you to have private conversations
over instant messaging by providing: Encryption No one else can read
your instant messages. Authentication You are assured the correspondent
is who you think it is. Deniability The messages you send do not have
digital signatures that are checkable by a third party. Anyone can
forge messages after a conversation to make them look like they came
from you. However, during a conversation, your correspondent is assured
the messages he sees are authentic and unmodified. Perfect forward
secrecy If you lose control of your private keys, no previous
conversation is compromised.

%package -n libotr5
Summary:        "Off The Record" messaging library toolkit
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
#openSUSE 10.3
Provides:       %{name} = %{version}
Obsoletes:      %{name} <= 3.0.0

%description -n libotr5
Off-the-Record (OTR) Messaging allows you to have private conversations
over instant messaging by providing: Encryption No one else can read
your instant messages. Authentication You are assured the correspondent
is who you think it is. Deniability The messages you send do not have
digital signatures that are checkable by a third party. Anyone can
forge messages after a conversation to make them look like they came
from you. However, during a conversation, your correspondent is assured
the messages he sees are authentic and unmodified. Perfect forward
secrecy If you lose control of your private keys, no previous
conversation is compromised.

%package devel
Summary:        Include files and development libraries
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Development/Libraries/C and C++
Requires:       libgcrypt-devel
Requires:       libotr5 = %{version}

%description devel
Headers and development libraries for libotr

%package tools
Summary:        "Off The Record" messaging library toolkit
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++

%description tools
Off-the-Record (OTR) Messaging allows you to have private conversations
over instant messaging by providing: Encryption No one else can read
your instant messages. Authentication You are assured the correspondent
is who you think it is. Deniability The messages you send do not have
digital signatures that are checkable by a third party. Anyone can
forge messages after a conversation to make them look like they came
from you. However, during a conversation, your correspondent is assured
the messages he sees are authentic and unmodified. Perfect forward
secrecy If you lose control of your private keys, no previous
conversation is compromised.

%prep
%autosetup -p1

%build
%ifarch %arm
export CFLAGS="%{optflags} -O1"
%else
export CFLAGS="%{optflags}"
%endif
%configure --disable-static --with-pic
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_libdir}/libotr.la

%files tools
%defattr (-, root, root)
%license COPYING
%{_bindir}/otr*
%{_mandir}/man1/otr*

%files -n libotr5
%defattr (-, root, root)
%license COPYING.LIB
%{_libdir}/libotr.so.5*

%files devel
%defattr (-, root, root)
%doc README AUTHORS NEWS ChangeLog
%license COPYING
%dir %{_includedir}/libotr
%{_includedir}/libotr/*.h
%{_libdir}/libotr.so
%{_datadir}/aclocal/libotr.m4
%{_libdir}/pkgconfig/libotr.pc

%post -n libotr5 -p /sbin/ldconfig
%postun -n libotr5 -p /sbin/ldconfig

%changelog
* Fri Nov 25 2022 Pedro Monreal <pmonreal@suse.com>
- Add sys/socket.h to the test suite that FTBFS without the include
  * Add libotr-4.1.1-include-socket.h.patch
* Thu Sep 27 2018 schwab@suse.de
- libotr-test-uninitialized.patch: Fix use of uninitialized memory in
  testsuite
- Don't disable testsuite on ppc
* Wed May 16 2018 adam.majer@suse.de
- Use %%license instead of %%doc for license files.
* Tue May 15 2018 mgorse@suse.com
- Add libotr-test-underrun.patch: fix intermittent buffer underrun
  in the regression test client (bsc#1091664).
* Mon Mar  7 2016 astieger@suse.com
- libotr 4.1.1:
  * Fix an integer overflow bug that can cause a heap buffer
    overflow (and from there remote code execution) on 64-bit
    platforms - CVE-2016-2851 (boo#969785)
  * Fix possible free() of an uninitialized pointer
  * Be stricter about parsing v3 fragments
  * Add a testsuite ("make check" to run it)
  * Fix a memory leak when reading a malformed instance tag file
  * Protocol documentation clarifications
- add libotr-4.1.1-fix-base64-tests.patch to fix test suite failure
- skip failing tests on ppc architectures
* Tue Oct 21 2014 andreas.stieger@gmx.de
- libotr 4.1.0:
  * Modernized autoconf build system
  * Use constant-time comparisons where needed
  * Use gcrypt secure memory allocation
  * Correctly reject attempts to fragment a message into too many
    pieces
  * Fix a missing opdata when sending message fragments
  * Don't lose the first user message when REQUIRE_ENCRYPTION is
    set
  * Fix some memory leaks
  * Correctly check for children contexts' state when forgetting a
    context
  * API Changes:
    + Added API functions otrl_context_find_recent_instance and
    otrl_context_find_recent_secure_instance.
- remove pass-opdata-when-sending-message-fragment.patch, upstream
- source tarball signature verification covered by source_validator
* Mon Jan  6 2014 hrvoje.senjan@gmail.com
- added patch from upstream:
  * pass-opdata-when-sending-message-fragment.patch -- fixes downstream
    kopete crashes: kde#328999, bnc#857501
* Wed Jun 19 2013 andreas.stieger@gmx.de
- verify source signature
- remove autoreconf call
* Wed Sep 26 2012 nmo.marques@gmail.com
- Update the license fields (bnc#782253)
- Move COPYING and COPYING.LIB documentation to their respective
  (sub)packages.
* Sun Sep 23 2012 nmo.marques@gmail.com
- Update to version 4.0.0:
  + Support v3 of the OTR protocol
  + The main new feature: sensibly handle the case where a user is
    logged in multiple times to the same IM account
  + instance tags, to support multiple simultaneous logins
  + support for asynchronous private key generation
  + the ability to provide an extra symmetric key to applications
    (with forward secrecy)
  + applications can supply a formation conversion callback if they
    do not natively use XHTML-style UTF8 markup
  + error messages formerly provided by libotr are now handled
    using callbacks to the application, for better i18n support
  + otrl_message_sending now handles message fragmentation
    internally
  + Added support for one-way authentication using an explicit
    question, based on the SOUPS 2008 user study
- Soname bump to 5
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Sep 23 2008 crrodriguez@suse.de
- update to version 3.2.0
  * dozen bugfixes, see Changelog for details
* Tue Oct  9 2007 crrodriguez@suse.de
- update to version 3.1.0
- run ldconfig
- make autobuild happy fixing the warnings
- fix devel package dependencies.
- remove static libraries
- use library packaging policy
* Sat Oct  7 2006 aj@suse.de
- Add dependency on base package.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 uli@suse.de
- build with -O1 on ARM (ICE workaround)
* Wed Nov  9 2005 bwhiteley@suse.de
- update to version 3.0.0
* Tue Nov  1 2005 bwhiteley@suse.de
- First time suse package (version 2.0.2)
